# ReColonyzer

[![Travis (.org)](https://img.shields.io/travis/judithbergada/recolonyzer?style=for-the-badge)](https://travis-ci.org/judithbergada/recolonyzer) [![PyPI](https://img.shields.io/pypi/v/recolonyzer?style=for-the-badge)](https://pypi.org/project/recolonyzer/) [![PyPI - License](https://img.shields.io/pypi/l/recolonyzer?style=for-the-badge)](https://github.com/judithbergada/recolonyzer/blob/master/LICENSE)

by Judith Bergadà Pijuan.

ReColonyzer is a software to quantify the cell density of bacterial cultures
from timecourse pictures. It uses image analysis tools to determine the fitness
of spotted cultures of bacteria grown on solid agar.

## Installation

ReColonyzer can be installed under Linux, macOS and Microsoft Windows.
It is available in PyPI for Python3.

To install the tool, please run this command in your terminal:

```bash
pip3 install recolonyzer
```

Further information on the installation can be found in the
[Installation Guide](https://judithbergada.github.io/recolonyzer/installation/).


## Usage

Basic information on how to use ReColonyzer can be obtained using
the `help` flag:

```bash
recolonyzer -h
```

ReColonyzer has two main commands available for the users. Try the following
if you want to get further information:

```bash
recolonyzer analyse -h
recolonyzer rename_images -h
```

Alternatively, you can visit the [ReColonyzer webpage](https://judithbergada.github.io/recolonyzer/usage/), where you will find
detailed documentation and instructions to use the tool.
We highly recommend to visit it in order to understand the input parameters as well as the outputs provided.
